@@ -50,7 +50,7 @@ use Data::Dumper;
 
 use vars qw($VERSION);
 
-$VERSION = '1.06';
+$VERSION = '1.07';
 
 =head1 METHODS
 
@@ -461,7 +461,11 @@ sub get_record {
     my $fh = $self->_filehandle;
 
 # how about an ensure_entry_count right here?
-# also a has_record
+    # also a has_record
+    if( $idx < 1 ) {
+        use Carp 'longmess'; print STDERR Data::Dumper->Dump([longmess]);
+        die "get record must be a positive integer";
+    }
    sysseek $fh, $self->{RECORD_SIZE} * ($idx-1), SEEK_SET or die "Could not seek ($self->{RECORD_SIZE} * ($idx-1)) : $@ $!";
     my $srv = sysread $fh, my $data, $self->{RECORD_SIZE};
     defined( $srv ) or die "Could not read : $@ $!";
@@ -527,7 +531,6 @@ sub put_record {
     my $to_write = pack ( $self->{TMPL}, ref $data ? @$data : $data );
 
     # allows the put_record to grow the data store by no more than one entry
-    use Carp 'longmess'; print STDERR Data::Dumper->Dump([longmess]) if $idx > (1+$self->entry_count);
     die "Index out of bounds" if $idx > (1+$self->entry_count);
 
     my $to_write_length = do { use bytes; length( $to_write ); };
